@@ -28,9 +28,9 @@ int _gnutls_recv_hello( gnutls_session session, char* data, int datalen);
 int gnutls_handshake( gnutls_session session);
 int _gnutls_recv_handshake( gnutls_session session, uint8**, int*, HandshakeType, Optional optional);
 int _gnutls_generate_session_id( char* session_id, uint8* len);
-int gnutls_handshake_common( gnutls_session session);
-int gnutls_handshake_client( gnutls_session session);
-int gnutls_handshake_server( gnutls_session session);
+int _gnutls_handshake_common( gnutls_session session);
+int _gnutls_handshake_client( gnutls_session session);
+int _gnutls_handshake_server( gnutls_session session);
 void _gnutls_set_server_random( gnutls_session session, uint8* random);
 void _gnutls_set_client_random( gnutls_session session, uint8* random);
 int _gnutls_create_random( opaque* dst);
